/*
 * Copyright (c) 2018 Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA. 
 *
 * $Id: //eng/uds-releases/flanders/kernelLinux/uds/sysfs.h#2 $
 */

#ifndef SYSFS_H
#define SYSFS_H

/**
 * Called when the module is loaded to initialize the /sys/<module_name>
 * tree.
 *
 * @return 0 on success, or non-zero on error
 **/
int initSysfs(void);

/**
 * Called when the module is being unloaded to terminate the
 * /sys/<module_name> tree.
 **/
void putSysfs(void);

#endif /*  SYSFS_H  */
